@@ -419,49 +419,22 @@ class SqlAlchemyDataset(MetaSqlAlchemyDataset):
             column_median = column_values[1][0]  # True center value
         return column_median
 
-    def _get_dialect_quantile_fn(self, allow_relative_error=False):
-        try:
-            # redshift
-            if isinstance(self.engine.dialect, sqlalchemy_redshift.dialect.RedshiftDialect):
-                if allow_relative_error is True:
-                    return "approximate percentile_disc"
-                raise ValueError("Redshift does not support computing quantiles without approximation error; set "
-                                 "allow_relative_error to True to allow approximate quantiles.")
-        except (AttributeError, TypeError):  # TypeError can occur if the driver was not installed and so is None
-            pass
-
-        # The remaining databases do not support relative error
-        if allow_relative_error is not False:
-            raise ValueError("Your current dialect does not support approximate quantile computation.")
-
-        try:
-            # postgres
-            if isinstance(self.engine.dialect, sa.dialects.postgresql.dialect):
-                return "percentile_disc"
-        except (AttributeError, TypeError):  # TypeError can occur if the driver was not installed and so is None
-            pass
-        try:
-            # Snowflake
-            if isinstance(self.engine.dialect, snowflake.sqlalchemy.snowdialect.SnowflakeDialect):
-                return "PERCENTILE_DISC"
-        except (AttributeError, TypeError):  # TypeError can occur if the driver was not installed and so is None
-            pass
-        try:
-            # Bigquery
-            if isinstance(self.engine.dialect, pybigquery.sqlalchemy_bigquery.BigQueryDialect):
-                return "PERCENTILE_DISC"
-        except (AttributeError, TypeError):  # TypeError can occur if the driver was not installed and so is None
-            pass
-
-        # NOTE - JPC - 20191117: I do not believe mysql, for example, actually supports percentile_disc,
-        # but using this as a default replicates the previous behavior and can stand until we add more robust testing
-        # and/or develop an alternative
-        return "PERCENTILE_DISC"
-
     def get_column_quantiles(self, column, quantiles, allow_relative_error=False):
-        quantile_fn = self._get_dialect_quantile_fn(allow_relative_error=allow_relative_error)
-        selects = [sa.sql.functions.Function(quantile_fn, str(quantile)).within_group(
+        selects = [sa.func.percentile_disc(quantile).within_group(
             sa.column(column).asc()) for quantile in quantiles]
+        try:
+            if isinstance(self.engine.dialect, sqlalchemy_redshift.dialect.RedshiftDialect):
+                # Redshift does not have a percentile_disc method, but does support an approximate version
+                if allow_relative_error is True:
+                    selects = [sa.text(
+                        ", ".join(["approximate " + str(stmt.compile(dialect=self.engine.dialect, compile_kwargs={
+                            'literal_binds': True})) for stmt in selects])
+                    )]
+                else:
+                    raise ValueError("Redshift does not support computing quantiles without approximation error; "
+                                     "set allow_relative_error to True to allow approximate quantiles.")
+        except (AttributeError, TypeError):
+            pass
         quantiles = self.engine.execute(sa.select(selects).select_from(self._table)).fetchone()
         return list(quantiles)
 
@@ -640,6 +613,19 @@ class SqlAlchemyDataset(MetaSqlAlchemyDataset):
 
         return sa.column(column) != None
 
+    def _get_dialect_type_module(self):
+        if self.dialect is None:
+            logger.warning("No sqlalchemy dialect found; relying in top-level sqlalchemy types.")
+            return sa
+        try:
+            # Redshift does not (yet) export types to top level; only recognize base SA types
+            if isinstance(self.engine.dialect, sqlalchemy_redshift.dialect.RedshiftDialect):
+                return self.dialect.sa
+        except (TypeError, AttributeError):
+            pass
+
+        return self.dialect
+
     @DocInherit
     @DataAsset.expectation(['column', 'type_', 'mostly'])
     def expect_column_values_to_be_of_type(
@@ -674,11 +660,8 @@ class SqlAlchemyDataset(MetaSqlAlchemyDataset):
                 # vacuously true
                 success = True
             else:
-                if self.dialect is None:
-                    logger.warning("No sqlalchemy dialect found; relying in top-level sqlalchemy types.")
-                    success = issubclass(col_type, getattr(sa, type_))
-                else:
-                    success = issubclass(col_type, getattr(self.dialect, type_))
+                type_module = self._get_dialect_type_module()
+                success = issubclass(col_type, getattr(type_module, type_))
 
             return {
                     "success": success,
@@ -722,30 +705,18 @@ class SqlAlchemyDataset(MetaSqlAlchemyDataset):
         if type_list is None:
             success = True
         else:
-            if self.dialect is None:
-                logger.warning("No sqlalchemy dialect found; relying in top-level sqlalchemy types.")
-                types = []
-                for type_ in type_list:
-                    try:
-                        type_class = getattr(sa, type_)
-                        types.append(type_class)
-                    except AttributeError:
-                        logger.debug("Unrecognized type: %s" % type_)
-                if len(types) == 0:
-                    logger.warning("No recognized sqlalchemy types in type_list")
-                types = tuple(types)
-            else:
-                types = []
-                for type_ in type_list:
-                    try:
-                        type_class = getattr(self.dialect, type_)
-                        types.append(type_class)
-                    except AttributeError:
-                        logger.debug("Unrecognized type: %s" % type_)
-                if len(types) == 0:
-                    logger.warning("No recognized sqlalchemy types in type_list for dialect %s" %
-                                   self.dialect.__name__)
-                types = tuple(types)
+            types = []
+            type_module = self._get_dialect_type_module()
+            for type_ in type_list:
+                try:
+                    type_class = getattr(type_module, type_)
+                    types.append(type_class)
+                except AttributeError:
+                    logger.debug("Unrecognized type: %s" % type_)
+            if len(types) == 0:
+                logger.warning("No recognized sqlalchemy types in type_list for dialect %s" %
+                               type_module.__name__)
+            types = tuple(types)
             success = issubclass(col_type, types)
 
         return {
