@@ -136,7 +136,6 @@ class Datasource(object):
         for generator in self._datasource_config["generators"].keys():
             self.get_generator(generator)
 
-
     def get_config(self):
         """
         Get the current configuration.
@@ -146,7 +145,8 @@ class Datasource(object):
         """
         return self._datasource_config
 
-    def _build_generator_from_config(self, **kwargs):
+    def build_generator(self, **kwargs):
+        """Build a generator using the provided configuration and return the newly-built generator."""
         if "type" in kwargs:
             warnings.warn("Using type to configure generators is now deprecated. Please use module_name and class_name"
                           "instead.")
@@ -184,7 +184,7 @@ class Datasource(object):
                 "type": generator_config
             }
         generator_config.update(kwargs)
-        generator = self._build_generator_from_config(**generator_config)
+        generator = self.build_generator(**generator_config)
         self._datasource_config["generators"][name] = generator_config
 
         return generator
@@ -206,7 +206,7 @@ class Datasource(object):
             raise ValueError(
                 "Unable to load generator %s -- no configuration found or invalid configuration." % generator_name
             )
-        generator = self._build_generator_from_config(**generator_config)
+        generator = self.build_generator(**generator_config)
         self._generators[generator_name] = generator
         return generator
 
@@ -390,27 +390,18 @@ class Datasource(object):
             **kwargs
         )
 
-    def named_generator_build_batch_kwargs(self, generator_name, generator_asset, *args, **kwargs):
+    def named_generator_build_batch_kwargs(self, generator_name, generator_asset, partition_id=None, **kwargs):
         """Use the named generator to build batch_kwargs"""
         generator = self.get_generator(generator_name=generator_name)
-        if len(args) == 1:  # We interpret a single argument as a partition_id
+        if partition_id:
             batch_kwargs = generator.build_batch_kwargs_from_partition_id(
                 generator_asset=generator_asset,
-                partition_id=args[0],
-                batch_kwargs=kwargs
-            )
-        elif len(args) > 0:
-            raise BatchKwargsError("Multiple positional arguments were provided to build_batch_kwargs, but only"
-                                   "one is supported. Please provide named arguments to build_batch_kwargs.")
-        elif "partition_id" in kwargs:
-            batch_kwargs = generator.build_batch_kwargs_from_partition_id(
-                generator_asset=generator_asset,
-                partition_id=kwargs["partition_id"],
-                batch_kwargs=kwargs
+                partition_id=partition_id,
+                **kwargs
             )
         else:
             if len(kwargs) > 0:
-                batch_kwargs = generator.yield_batch_kwargs(generator_asset, kwargs)
+                batch_kwargs = generator.yield_batch_kwargs(generator_asset, **kwargs)
             else:
                 raise BatchKwargsError(
                     "Unable to build batch_kwargs: no partition_id or base kwargs found to pass to generator.",
