@@ -29,13 +29,14 @@ class SparkDFDatasource(Datasource):
     """
 
     @classmethod
-    def build_configuration(cls, data_asset_type=None, generators=None, **kwargs):
+    def build_configuration(cls, data_asset_type=None, generators=None, spark_config=None, **kwargs):
         """
         Build a full configuration object for a datasource, potentially including generators with defaults.
 
         Args:
             data_asset_type: A ClassConfig dictionary
             generators: Generator configuration dictionary
+            spark_config: dictionary of key-value pairs to pass to the spark builder
             **kwargs: Additional kwargs to be part of the datasource constructor's initialization
 
         Returns:
@@ -65,15 +66,32 @@ class SparkDFDatasource(Datasource):
             except TypeError:
                 # In this case, we allow the passed config, for now, in case they're using a legacy string-only config
                 pass
+
+        if spark_config is None:
+            spark_config = {}
+
         configuration = kwargs
         configuration.update({
             "data_asset_type": data_asset_type,
             "generators": generators,
+            "spark_config": spark_config
         })
         return configuration
 
-    def __init__(self, name="default", data_context=None, data_asset_type=None, generators=None, **kwargs):
-        configuration_with_defaults = SparkDFDatasource.build_configuration(data_asset_type, generators, **kwargs)
+    def __init__(self, name="default", data_context=None, data_asset_type=None, generators=None,
+                 spark_config=None, **kwargs):
+        """Build a new SparkDFDatasource instance.
+
+        Args:
+            name: the name of this datasource
+            data_context: the DataContext to which this datasource is connected
+            data_asset_type: ClassConfig describing the data_asset type to be constructed by this datasource
+            generators: generator configuration
+            spark_config: dictionary of key-value pairs to be set on the spark session builder
+            **kwargs: Additional
+        """
+        configuration_with_defaults = SparkDFDatasource.build_configuration(data_asset_type, generators,
+                                                                            spark_config, **kwargs)
         data_asset_type = configuration_with_defaults.pop("data_asset_type")
         generators = configuration_with_defaults.pop("generators")
         super(SparkDFDatasource, self).__init__(
@@ -84,7 +102,10 @@ class SparkDFDatasource(Datasource):
             **configuration_with_defaults)
 
         try:
-            self.spark = SparkSession.builder.getOrCreate()
+            builder = SparkSession.builder
+            for k, v in configuration_with_defaults["spark_config"].items():
+                builder.config(k, v)
+            self.spark = builder.getOrCreate()
         except AttributeError:
             logger.error("Unable to load spark context; install optional spark dependency for support.")
             self.spark = None
