@@ -109,3 +109,24 @@ def test_subdir_reader_file_partitioning(tmp_path_factory):
                                                                           limit=10)
     assert kwargs["path"] == os.path.join(base_directory, "20190101__asset_1.csv")
     assert kwargs["limit"] == 10
+
+
+def test_subdir_reader_configurable_reader_method(tmp_path_factory):
+    base_directory = str(tmp_path_factory.mktemp("test_folder_connection_path"))
+    mock_files = [
+        "20190101__asset_1.dat",
+        "20190102__asset_1.dat",
+        "20190103__asset_1.dat",
+        "asset_2/20190101__asset_2.dat",
+        "asset_2/20190102__asset_2.dat"
+    ]
+    for file in mock_files:
+        if "/" in file:
+            safe_mmkdir(os.path.join(base_directory, file.split("/")[0]))
+        open(os.path.join(base_directory, file), "w").close()
+
+    # If we have files, we should see them as individual assets
+    subdir_reader_generator = SubdirReaderGenerator("test_generator", base_directory=base_directory,
+                                                    reader_method='csv', known_extensions=['.dat'])
+    batch_kwargs = next(subdir_reader_generator.get_iterator('asset_2'))
+    assert batch_kwargs['reader_method'] == 'csv'
